@@ -1,4 +1,4 @@
-from typing import Union, Mapping, TYPE_CHECKING
+from typing import Union, Mapping, TYPE_CHECKING, Dict, Any
 
 from pydantic import BaseModel
 from pydantic.main import ModelMetaclass
@@ -7,6 +7,7 @@ from sqlalchemy import select, func, Table, exists
 from fox_orm import FoxOrm
 from fox_orm.exceptions import OrmException
 from fox_orm.relations import ManyToMany
+from fox_orm.utils import validate_model, class_or_instancemethod
 
 if TYPE_CHECKING:
     # pylint: disable=no-name-in-module,ungrouped-imports
@@ -44,6 +45,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         validate_assignment = True
 
     # cls attrs
+    __private_attributes__: Dict[str, Any]
     __sqla_table__: Table
     __exclude__: set
 
@@ -62,12 +64,20 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
                 self.__dict__[i] = self.__fields__[i].default._init_copy(self)  # pylint: disable=protected-access
         super()._init_private_attributes()
 
+    def __init__(self, **data: Any) -> None:  # pylint: disable=super-init-not-called
+        values, fields_set, validation_error = validate_model(self.__class__, data)
+        if validation_error:
+            raise validation_error  # pylint: disable=raising-bad-type
+        object.__setattr__(self, '__dict__', values)
+        object.__setattr__(self, '__fields_set__', fields_set)
+        self._init_private_attributes()
+
     # pylint: disable=unsubscriptable-object, too-many-arguments
     def _iter(self, to_dict: bool = False, by_alias: bool = False,
               include: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None,
               exclude: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None, exclude_unset: bool = False,
               exclude_defaults: bool = False, exclude_none: bool = False) -> 'TupleGenerator':
-        exclude_private = self.__exclude__ | EXCLUDE_KEYS
+        exclude_private = self.__exclude__ - {'id'} | EXCLUDE_KEYS
         if exclude is None:
             exclude = exclude_private
         elif isinstance(exclude, Mapping):  # pylint: disable=isinstance-second-argument-not-valid-type
@@ -89,11 +99,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return super().__setattr__(name, value)
 
     @classmethod
-    def parse_obj(cls, *args, **kwargs):
-        raise OrmException('Do not use parse_obj with OrmModel')
-
-    @classmethod
-    def construct(cls, values):
+    def construct(cls, values):  # pylint: disable=arguments-differ
         m = cls.__new__(cls)
         fields_values = {name: field.get_default() for name, field in cls.__fields__.items() if
                          not field.required and field.name not in cls.__exclude__}
@@ -124,7 +130,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
             self.__modified__ = set()
         else:
             table = self.__class__.__sqla_table__
-            data = self.dict()
+            data = self.dict(exclude={'id'})
             self.id = await FoxOrm.db.execute(table.insert(), data)  # pylint: disable=attribute-defined-outside-init
             self.__bound__ = True
 
@@ -145,20 +151,22 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return query
 
     @classmethod
-    async def select(cls, where, *, order_by=None):
+    async def select(cls, where, *, order_by=None, skip_parsing=False):
+        construct_func = cls.construct if skip_parsing else cls.parse_obj
         res = await FoxOrm.db.fetch_one(cls._generate_query(where, order_by, None, None))
         if not res:
             return None
-        res = cls.construct(res)
+        res = construct_func(res)
         res.__bound__ = True
         return res
 
     @classmethod
-    async def select_all(cls, where, *, order_by=None, limit=None, offset=None):
+    async def select_all(cls, where, *, order_by=None, limit=None, offset=None, skip_parsing=False):
+        construct_func = cls.construct if skip_parsing else cls.parse_obj
         q_res = await FoxOrm.db.fetch_all(cls._generate_query(where, order_by, limit, offset))
         res = []
         for x in q_res:
-            res.append(cls.construct(dict(x)))
+            res.append(construct_func(x))
             res[-1].__bound__ = True
         return res
 
@@ -169,10 +177,25 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return await FoxOrm.db.fetch_val(query)
 
     @classmethod
-    async def delete(cls, where):
+    async def _delete_cls(cls, where):
         query = cls.__sqla_table__.delete().where(where)
         return await FoxOrm.db.execute(query)
 
+    async def _delete_inst(self):
+        self.ensure_id()
+        table = self.__class__.__sqla_table__
+        query = table.delete().where(table.c.id == self.id)
+        self.__bound__ = False
+        return await FoxOrm.db.execute(query)
+
+    # pylint: disable=bad-classmethod-argument,no-else-return
+    @class_or_instancemethod
+    async def delete(self_or_cls, *args, **kwargs):
+        if isinstance(self_or_cls, type):
+            return await self_or_cls._delete_cls(*args, **kwargs)
+        else:
+            return await self_or_cls._delete_inst(*args, **kwargs)
+
     @classmethod
     async def count(cls, where):
         query = select([func.count()]).select_from(cls.__sqla_table__)
@@ -181,8 +204,8 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return await FoxOrm.db.fetch_val(query)
 
     @classmethod
-    async def get(cls, obj_id: int):
-        return await cls.select(cls.__sqla_table__.c.id == obj_id)
+    async def get(cls, obj_id: int, skip_parsing=False):
+        return await cls.select(cls.__sqla_table__.c.id == obj_id, skip_parsing=skip_parsing)
 
     async def _fetch_related(self, field: str):
         self.ensure_id()
